function x = vecDot(a, b)
% vecDot - Dot product for vectors in R2
%   
% 
%   Syntax: 
%           x = vecDot(a, b)
%   Arguments: 
%           a - The first vector
%           b - The second vector
%   Returns: 
%           x - The scalar product of a and b
%           
%   Description:
%
%           Computes the scalar product between two vectors in R2
%           
%   See also:
%

%----------------------------------------------------------------------
%   Bugs:
%
%   Date created: 
%          990910
%   Author:
%          Stig Larsson
%
%   Change history:
%
%                              +---------------------------------------+ 
%                              |     Matematik Kf/Kb 1999-2000         | 
%                              |     Copyright (c) 1999                | 
%                              |                                       | 
%                              |     Stig Larsson                      | 
%                              |     Mathematics                       | 
%                              |     Chalmers University of Technology | 
%                              |     SE-412 96 Goteborg                | 
%                              |     SWEDEN                            |     
%                              |     stig@math.chalmers.se             |     
%                              |     http://www.math.chalmers.se/~stig |     
%------------------------------+---------------------------------------+
